#[non_exhaustive]pub enum ReplicaFallback {
FailReadiness,
Primary,
}Expand description
Behavior when a configured read replica is unavailable or stale.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailReadiness
Readiness should fail when the configured replica cannot safely serve reads.
Primary
Read paths may use the primary when the replica is unavailable or stale.