Flags

Struct Flags 

pub struct Flags { /* private fields */ }
Request extractor that resolves the current user’s flag service handle.

Extracts FeatureFlagService from the AppState extension slot. If no service is registered the extraction fails with 500 Internal Server Error.

use autumn_web::prelude::*;
use autumn_web::feature_flags::Flags;

#[get("/dashboard")]
async fn dashboard(flags: Flags) -> Markup {
    html! {
        @if flags.enabled("beta_inbox") {
            (render_beta_inbox())
        }
    }
}

Implementations

Source

impl Flags

pub fn enabled(&self, flag_key: &str) -> bool

Return true if flag_key is enabled for the current actor.

pub const fn service(&self) -> &FeatureFlagService

Return the underlying service for direct mutation from handlers.