pub struct Dir<'a> { /* private fields */ }Expand description
A directory.
Implementations
Sourceimpl<'a> Dir<'a>
impl<'a> Dir<'a>
Sourcepub fn path(&self) -> &'a Path
pub fn path(&self) -> &'a Path
The full path for this Dir, relative to the directory passed to
crate::include_dir!().
Sourcepub fn files(&self) -> impl Iterator<Item = &'a File<'a>> + 'a
pub fn files(&self) -> impl Iterator<Item = &'a File<'a>> + 'a
Get a list of the files in this directory.
Sourcepub fn dirs(&self) -> impl Iterator<Item = &'a Dir<'a>> + 'a
pub fn dirs(&self) -> impl Iterator<Item = &'a Dir<'a>> + 'a
Get a list of the sub-directories inside this directory.
Sourcepub fn get_entry<S>(&self, path: S) -> Option<&'a DirEntry<'a>>
pub fn get_entry<S>(&self, path: S) -> Option<&'a DirEntry<'a>>
Recursively search for a DirEntry with a particular path.
Sourcepub fn extract<S>(&self, base_path: S) -> Result<(), Error>
pub fn extract<S>(&self, base_path: S) -> Result<(), Error>
Create directories and extract all files to real filesystem.
Creates parent directories of path if they do not already exist.
Fails if some files already exist.
In case of error, partially extracted directory may remain on the filesystem.