Plugins

Trait Plugins 

pub trait Plugins: Sized {
    // Required method
    fn apply(self, app: AppBuilder) -> AppBuilder;
}
A bundle of plugins that can be applied to an AppBuilder in one call.

Implemented for every Plugin and for tuples of up to eight plugins. Used by AppBuilder::plugins.

Required Methods

fn apply(self, app: AppBuilder) -> AppBuilder

Apply every plugin in this bundle to the builder, in declaration order.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<P0: Plugin> Plugins for (P0,)

Source

impl<P0: Plugin, P1: Plugin> Plugins for (P0, P1)

Source

impl<P0: Plugin, P1: Plugin, P2: Plugin> Plugins for (P0, P1, P2)

Source

impl<P0: Plugin, P1: Plugin, P2: Plugin, P3: Plugin> Plugins for (P0, P1, P2, P3)

Source

impl<P0: Plugin, P1: Plugin, P2: Plugin, P3: Plugin, P4: Plugin> Plugins for (P0, P1, P2, P3, P4)

Source

impl<P0: Plugin, P1: Plugin, P2: Plugin, P3: Plugin, P4: Plugin, P5: Plugin> Plugins for (P0, P1, P2, P3, P4, P5)

Source

impl<P0: Plugin, P1: Plugin, P2: Plugin, P3: Plugin, P4: Plugin, P5: Plugin, P6: Plugin> Plugins for (P0, P1, P2, P3, P4, P5, P6)

Source

impl<P0: Plugin, P1: Plugin, P2: Plugin, P3: Plugin, P4: Plugin, P5: Plugin, P6: Plugin, P7: Plugin> Plugins for (P0, P1, P2, P3, P4, P5, P6, P7)

Implementors

Source

impl<P: Plugin> Plugins for P