Method

Struct Method 

pub struct Method(/* private fields */);
HTTP methods — pass to crate::links::button_to/crate::links::button_to_with. The Request Method (VERB)

This type also contains constants for a number of common HTTP methods such as GET, POST, etc.

Currently includes 8 variants representing the 8 methods defined in RFC 7230, plus PATCH, and an Extension variant for all extensions.

Examples

use http::Method;

assert_eq!(Method::GET, Method::from_bytes(b"GET").unwrap());
assert!(Method::GET.is_idempotent());
assert_eq!(Method::POST.as_str(), "POST");

Implementations

Source

impl Method

pub const GET: Method

GET

pub const POST: Method

POST

pub const PUT: Method

PUT

pub const DELETE: Method

DELETE

pub const HEAD: Method

HEAD

pub const OPTIONS: Method

OPTIONS

pub const CONNECT: Method

CONNECT

pub const PATCH: Method

PATCH

pub const TRACE: Method

TRACE

pub fn from_bytes(src: &[u8]) -> Result<Method, InvalidMethod>

Converts a slice of bytes to an HTTP method.

pub fn is_safe(&self) -> bool

Whether a method is considered “safe”, meaning the request is essentially read-only.

See the spec for more words.

pub fn is_idempotent(&self) -> bool

Whether a method is considered “idempotent”, meaning the request has the same result if executed multiple times.

See the spec for more words.

pub fn as_str(&self) -> &str

Return a &str representation of the HTTP method