#[non_exhaustive]pub enum SessionBackendConfigError {
MissingRedisUrl,
InvalidRedisUrl(String),
RedisFeatureDisabled,
}Expand description
Errors that can occur when resolving the session backend configuration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingRedisUrl
Redis was selected, but no URL was provided.
InvalidRedisUrl(String)
The provided Redis URL could not be parsed.
RedisFeatureDisabled
Redis was selected, but the redis crate feature is not enabled.