Session

Struct Session 

pub struct Session { /* private fields */ }
A handle to the current request’s session data.

Obtained via the Session Axum extractor. All reads and writes go through interior mutability so the extractor can be shared.

Changes are written back to the store automatically when the response is sent (via SessionLayer).

Implementations

Source

impl Session

pub async fn id(&self) -> String

Returns the session ID.

pub async fn get(&self, key: &str) -> Option<String>

Get a value from the session.

pub async fn insert(&self, key: impl Into<String>, value: impl Into<String>)

Insert a key-value pair into the session.

pub async fn remove(&self, key: &str) -> Option<String>

Remove a key from the session, returning the previous value.

pub async fn clear(&self)

Remove all data from the session (but keep the session ID).

pub async fn rotate_id(&self)

Rotate the session ID, generating a new ID for the same data.

This is critical to call during privilege elevation (e.g., login) to prevent Session Fixation attacks.

pub async fn destroy(&self)

Destroy the session entirely. A new session ID will be issued on the next request.

pub async fn contains_key(&self, key: &str) -> bool

Returns true if this session contains the given key.