SessionStoreError

Struct SessionStoreError 

pub struct SessionStoreError { /* private fields */ }
An error that occurred during a session store operation.

Implementations

Source

impl SessionStoreError

pub fn backend(operation: &'static str, error: impl Display) -> Self

Create a new session store error from an underlying backend error.