pub fn insert<V: Clone + Send + Sync + 'static>(
cache: &dyn Cache,
key: &str,
value: V,
)Expand description
Typed insert: wrap the value in an Arc and store it.
Works with any Cache implementation.
For cross-replica backends (Redis) use insert_cached instead,
which also serializes the value for storage across process boundaries.