pub struct AutumnError { /* private fields */ }Expand description
Framework error type wrapping any error with an HTTP status code.
Usage
The ? operator converts any std::error::Error into an AutumnError
with status 500 Internal Server Error:
use autumn_web::prelude::*;
#[get("/")]
async fn handler() -> AutumnResult<&'static str> {
std::fs::read_to_string("missing.txt")?; // becomes 500 on error
Ok("ok")
}For expected errors, use a status refinement constructor:
use autumn_web::prelude::*;
#[get("/users/{id}")]
async fn get_user(axum::extract::Path(id): axum::extract::Path<i32>) -> AutumnResult<String> {
if id < 0 {
return Err(AutumnError::bad_request(
std::io::Error::other("id must be positive"),
));
}
Ok(format!("user {id}"))
}Why no Error impl
AutumnError intentionally does not implement std::error::Error.
Doing so would conflict with the blanket From<E: Error> impl (the
reflexive From<T> for T would overlap). This type is a response
wrapper, not a propagatable error.
Implementations
Sourceimpl AutumnError
impl AutumnError
Sourcepub const fn with_status(self, status: StatusCode) -> Self
pub const fn with_status(self, status: StatusCode) -> Self
Override the HTTP status code.
Examples
use autumn_web::error::AutumnError;
use http::StatusCode;
let err: AutumnError = std::io::Error::other("forbidden").into();
let err = err.with_status(StatusCode::FORBIDDEN);
assert_eq!(err.status(), StatusCode::FORBIDDEN);Sourcepub fn not_found(err: impl Error + Send + Sync + 'static) -> Self
pub fn not_found(err: impl Error + Send + Sync + 'static) -> Self
Create a 404 Not Found error.
Examples
use autumn_web::error::AutumnError;
use http::StatusCode;
let err = AutumnError::not_found(std::io::Error::other("no such user"));
assert_eq!(err.status(), StatusCode::NOT_FOUND);Sourcepub fn bad_request(err: impl Error + Send + Sync + 'static) -> Self
pub fn bad_request(err: impl Error + Send + Sync + 'static) -> Self
Create a 400 Bad Request error.
Examples
use autumn_web::error::AutumnError;
use http::StatusCode;
let err = AutumnError::bad_request(std::io::Error::other("invalid input"));
assert_eq!(err.status(), StatusCode::BAD_REQUEST);Sourcepub fn unprocessable(err: impl Error + Send + Sync + 'static) -> Self
pub fn unprocessable(err: impl Error + Send + Sync + 'static) -> Self
Create a 422 Unprocessable Entity error.
Use this for validation failures where the request is syntactically valid but semantically incorrect.
Examples
use autumn_web::error::AutumnError;
use http::StatusCode;
let err = AutumnError::unprocessable(std::io::Error::other("age must be positive"));
assert_eq!(err.status(), StatusCode::UNPROCESSABLE_ENTITY);Create a 503 Service Unavailable error.
Examples
use autumn_web::error::AutumnError;
use http::StatusCode;
let err = AutumnError::service_unavailable(std::io::Error::other("pool exhausted"));
assert_eq!(err.status(), StatusCode::SERVICE_UNAVAILABLE);Sourcepub fn not_found_msg(msg: impl Into<String>) -> Self
pub fn not_found_msg(msg: impl Into<String>) -> Self
Create a 404 Not Found error from a plain string message.
Sourcepub fn bad_request_msg(msg: impl Into<String>) -> Self
pub fn bad_request_msg(msg: impl Into<String>) -> Self
Create a 400 Bad Request error from a plain string message.
Sourcepub fn unprocessable_msg(msg: impl Into<String>) -> Self
pub fn unprocessable_msg(msg: impl Into<String>) -> Self
Create a 422 Unprocessable Entity error from a plain string message.
Create a 503 Service Unavailable error from a plain string message.
Sourcepub const fn status(&self) -> StatusCode
pub const fn status(&self) -> StatusCode
Returns the HTTP status code associated with this error.
Examples
use autumn_web::error::AutumnError;
use http::StatusCode;
let err: AutumnError = std::io::Error::other("boom").into();
assert_eq!(err.status(), StatusCode::INTERNAL_SERVER_ERROR);Trait Implementations
Sourceimpl Debug for AutumnError
impl Debug for AutumnError
Sourceimpl Display for AutumnError
impl Display for AutumnError
Sourceimpl<E> From<E> for AutumnError
impl<E> From<E> for AutumnError
Sourceimpl IntoResponse for AutumnError
impl IntoResponse for AutumnError
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response