pub trait Plugins: Sized {
// Required method
fn apply(self, app: AppBuilder) -> AppBuilder;
}Expand description
A bundle of plugins that can be applied to an AppBuilder in one call.
Implemented for every Plugin and for tuples of up to eight plugins.
Used by AppBuilder::plugins.
Required Methods
Sourcefn apply(self, app: AppBuilder) -> AppBuilder
fn apply(self, app: AppBuilder) -> AppBuilder
Apply every plugin in this bundle to the builder, in declaration order.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.