pub struct Session { /* private fields */ }Expand description
A handle to the current request’s session data.
Obtained via the Session Axum extractor. All reads and writes
go through interior mutability so the extractor can be shared.
Changes are written back to the store automatically when the
response is sent (via SessionLayer).
Implementations
Sourceimpl Session
impl Session
Sourcepub async fn insert(&self, key: impl Into<String>, value: impl Into<String>)
pub async fn insert(&self, key: impl Into<String>, value: impl Into<String>)
Insert a key-value pair into the session.
Sourcepub async fn remove(&self, key: &str) -> Option<String>
pub async fn remove(&self, key: &str) -> Option<String>
Remove a key from the session, returning the previous value.
Sourcepub async fn rotate_id(&self)
pub async fn rotate_id(&self)
Rotate the session ID, generating a new ID for the same data.
This is critical to call during privilege elevation (e.g., login) to prevent Session Fixation attacks.
Sourcepub async fn destroy(&self)
pub async fn destroy(&self)
Destroy the session entirely. A new session ID will be issued on the next request.
Sourcepub async fn contains_key(&self, key: &str) -> bool
pub async fn contains_key(&self, key: &str) -> bool
Returns true if this session contains the given key.